@@ -3,7 +3,8 @@ from typing import List
 from datetime import datetime
 from gql.transport.exceptions import TransportQueryError
 
-from wton.tonsdk.utils import to_nano, TonCurrencyEnum, from_nano, Address, b64str_to_bytes, bytes_to_b64str
+from wton.tonsdk.utils import to_nano, TonCurrencyEnum, from_nano, Address, b64str_to_bytes, \
+    bytes_to_b64str
 from wton.tonsdk.boc import Cell
 from wton.tonsdk.contract.wallet import SendModeEnum, WalletContract
 from wton.config import Config
@@ -69,16 +70,19 @@ class DAppTonClient(TonClient):
 
         return self._parse_broadcast_result(result, wait_for_result)
 
-    def transfer(self, from_wallet: WalletContract, to_addr: str, amount: TonCurrencyEnum.ton, payload=None,
-                 send_mode=SendModeEnum.ignore_errors | SendModeEnum.pay_gas_separately, wait_for_result=False):
+    def transfer(self, from_wallet: WalletContract, to_addr: str,
+                 amount: TonCurrencyEnum.ton, payload=None,
+                 send_mode=SendModeEnum.ignore_errors | SendModeEnum.pay_gas_separately,
+                 is_bounceable=True, wait_for_result=False, state_init=None):
         timeout = 30 if wait_for_result else 0
         seqno = self.seqno(from_wallet.address.to_string())
         query = from_wallet.create_transfer_message(
-            to_addr=Address(to_addr).to_string(False, False, True),  # TODO: set is bounceable or not
+            to_addr=Address(to_addr).to_string(True, False, is_bounceable),
             amount=to_nano(amount, TonCurrencyEnum.ton),
             seqno=seqno,
             payload=payload,
             send_mode=send_mode,
+            state_init=state_init,
         )
         msg_boc = query["message"].to_boc(False)
         base64_boc = bytes_to_b64str(msg_boc)
@@ -87,6 +91,14 @@ class DAppTonClient(TonClient):
 
         return self._parse_broadcast_result(result, wait_for_result)
 
+    def send_boc(self, boc: bytes, wait_for_result: bool):
+        timeout = 30 if wait_for_result else 0
+        base64_boc = bytes_to_b64str(boc)
+        result = self._run(self.provider.broadcast(
+            [BroadcastQuery(boc=base64_boc, timeout=timeout)]))
+
+        return self._parse_broadcast_result(result, wait_for_result)
+
     def _run(self, to_run, *, single_query=True):
         try:
             results = self.loop.run_until_complete(to_run)
