@@ -114,7 +114,7 @@ class Address:
         if is_test_only is None:
             is_test_only = self.is_test_only
 
-        if not is_user_friendly:
+        if not is_user_friendly:  # FIXME: ignores other flags here!
             return f"{self.wc}:{self.hash_part.hex()}"
         else:
             tag = Address.BOUNCEABLE_TAG if is_bounceable else Address.NON_BOUNCEABLE_TAG
