@@ -72,12 +72,14 @@ def with_keystore(password_required: bool):
                 raise CustomClickException(e)
 
             return func(*args, **kwargs)
+
         return without_password_wrapper
 
     def with_password(func):
         @click.pass_obj
         @click.password_option(default=settings.KEYSTORE_PASSWORD,
-                               confirmation_prompt=False, prompt=False if settings.KEYSTORE_PASSWORD else True)
+                               confirmation_prompt=False,
+                               prompt=False if settings.KEYSTORE_PASSWORD else True)
         @wraps(func)
         def with_password_wrapper(shared_object, password, *args, **kwargs):
             keystores = KeyStores(
@@ -107,3 +109,7 @@ class HiddenPassword(object):
 
     def __str__(self):
         return '*' * len(self.password)
+
+
+def y_n_to_bool(ctx, param, value):
+    return value == "y"
