@@ -58,12 +58,12 @@ class KeystoreSet(BaseSet):
 
                 for wallet, wallet_info in zip(wallets, wallet_infos):
                     table.add_row([wallet.name, wallet.version, wallet.workchain,
-                                wallet.address_to_show, wallet.comment,
-                                wallet_info.state, wallet_info.balance])
+                                   wallet.address_to_show, wallet.comment,
+                                   wallet_info.state, wallet_info.balance])
             else:
                 for wallet in wallets:
                     table.add_row([wallet.name, wallet.version, wallet.workchain,
-                                wallet.address_to_show, wallet.comment])
+                                   wallet.address_to_show, wallet.comment])
 
         echo_success(table, only_msg=True)
 
@@ -113,9 +113,10 @@ class KeystoreSet(BaseSet):
         with self._processing():
             _mnemonics, _pub_k, _priv_k, wallet = Wallets.from_mnemonics(mnemonics, record.version,
                                                                          record.workchain)
-            # TonDappError('timeout, Code: 0')
+
+            # always send money in one direction without bouncing
             result = self.ctx.ton_client.transfer(
-                wallet, contact.address, amount, message, send_mode, wait_for_result)
+                wallet, contact.address, amount, message, send_mode, False, wait_for_result)
 
         echo_success(result)
 
@@ -146,7 +147,8 @@ class KeystoreSet(BaseSet):
             comment = ans["comment"]
             questions = [
                 inquirer.Text(
-                    "contact_name", message='Enter name to save to whitelist (blank to skip)', default=name),
+                    "contact_name", message='Enter name to save to whitelist (blank to skip)',
+                    default=name),
             ]
             contact_name = self._prompt(questions)["contact_name"]
 
@@ -215,8 +217,8 @@ class KeystoreSet(BaseSet):
                 mnemonics, pub_k, _priv_k, wallet = Wallets.create(
                     version, workchain)
                 self.ctx.keystore.add_record(wallet_name, wallet.address,
-                                            pub_k.hex(), mnemonics, version,
-                                            workchain, comment, save=False)
+                                             pub_k.hex(), mnemonics, version,
+                                             workchain, comment, save=False)
 
                 if contact_name:
                     self.ctx.whitelist.add_contact(
@@ -335,9 +337,10 @@ class KeystoreSet(BaseSet):
 
         questions = [
             inquirer.Confirm(
-                "is_sure", message=confirm_phrase, default=False,),
+                "is_sure", message=confirm_phrase, default=False, ),
             inquirer.Confirm(
-                "delete_whitelist", message="Do you want to delete whitelist contacts with the same names?", default=False)
+                "delete_whitelist",
+                message="Do you want to delete whitelist contacts with the same names?", default=False)
         ]
         ans = self._prompt(questions)
         is_sure = ans["is_sure"]
